package cn.com.ctop.kuaishou.modules.report.mapper;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import org.apache.ibatis.annotations.Param;

import java.util.List;

public interface KsNewPlanReportMapper {

    List<JSONObject> queryKsNewPlanGroupByAccount(@Param("accountIds") JSONArray accountIds, @Param("startDate") String startDate, @Param("endDate") String endDate,@Param("target") String target,@Param("order") String order);

    List<JSONObject> queryKsNewPlanGroupByStatDate(@Param("accountIds") JSONArray accountIds, @Param("startDate") String startDate, @Param("endDate") String endDate);

    List<JSONObject> queryKsNewPlanGroupByMonth(@Param("accountIds") JSONArray accountIds, @Param("startDate") String startDate, @Param("endDate") String endDate);

    JSONObject querySumNewPlanBy(@Param("accountIds") JSONArray accountIds, @Param("startDate") String startDate, @Param("endDate") String endDate);

    List<JSONObject> queryAllOperator();

    JSONArray queryAccountIdsByUserId(String userId);

    JSONArray queryAccountIdsByMedia();

}
